

#include <MozziGuts.h>
#include <Oscil.h> // oscillator 
#include <tables/cos2048_int8.h> // table for Oscils to play
#include <Smooth.h>
#include <AutoMap.h> // maps unpredictable inputs to a range
#include <tables/sin2048_int8.h> // sine table for oscillator
// use: Oscil <table_size, update_rate> oscilName (wavetable), look in .h file of table #included above
Oscil <SIN2048_NUM_CELLS, AUDIO_RATE> aSin(SIN2048_DATA);
// use #define for CONTROL_RATE, not a constant
#define CONTROL_RATE 64 // powers of 2 please
// desired carrier frequency max and min, for AutoMap
const int MIN_CARRIER_FREQ = 10;
const int MAX_CARRIER_FREQ = 1200;

// desired intensity max and min, for AutoMap, note they're inverted for reverse dynamics
const int MIN_INTENSITY = 0;
const int MAX_INTENSITY2 = 1000;

// desired mod speed max and min, for AutoMap, note they're inverted for reverse dynamics
const int MIN_MOD_SPEED = 20000;
const int MAX_MOD_SPEED = 5;

AutoMap kMapCarrierFreq(0,1023,MAX_CARRIER_FREQ, MIN_CARRIER_FREQ);
AutoMap kMapIntensity(0,1023,MAX_INTENSITY2,MIN_INTENSITY);
AutoMap kMapModSpeed(0,1023,MIN_MOD_SPEED,MAX_MOD_SPEED);


///pins and things
const int ledPin =  2;// the number of the LED pin
int tempoPin = A1;
const int Pitch_Pin = A3; //PITCH set the input for the knob
const int LDR1_PIN = A2; // INTENSITYset the analog input for fm_intensity
const int LDR2_PIN = A0; // RATE set the analog input for mod rate
int mode1Pin = A4;//two selector switches
int mode2Pin = A5;
int ModeSelector1 = analogRead(mode1Pin);
int ModeSelector2 = analogRead(mode2Pin);


int modePin = 3; 
int modeSwitch = LOW; //int testD10 = digitalRead(10);
int volumeCont = 1; //volume control
int triggerPin = 4;
// Variables will change :
int ledState = LOW;             // ledState used to set the LED
int pulseOn =0;
// Generally, you should use "unsigned long" for variables that hold time
// The value will quickly become too large for an int to store
unsigned long previousMillis = millis();  
unsigned long previousMillis2  = millis(); // will store last time LED was updated

// constants won't change :
unsigned long interval = 1000;


Oscil<COS2048_NUM_CELLS, AUDIO_RATE> aCarrier(COS2048_DATA);
Oscil<COS2048_NUM_CELLS, AUDIO_RATE> aModulator(COS2048_DATA);
Oscil<COS2048_NUM_CELLS, CONTROL_RATE> kIntensityMod(COS2048_DATA);

int mod_ratio = 5; // brightness (harmonics)
long fm_intensity; // carries control info from updateControl to updateAudio

// smoothing for intensity to remove clicks on transitions
float smoothness = 0.95f;
Smooth <long> aSmoothIntensity(smoothness);


void setup(){
//Serial.begin(9600); // for Teensy 3.1, beware printout can cause glitches
 // Serial.begin(115200); // set up the Serial output so we can look at the piezo values // set up the Serial output so we can look at the light level
  startMozzi(); // :))
  pinMode(triggerPin, OUTPUT);
}


void updateControl(){

ModeSelector1 = mozziAnalogRead(mode1Pin);
ModeSelector1 = map(ModeSelector1, 0, 1200, 0, 8);
ModeSelector2 = mozziAnalogRead(mode2Pin);


interval = mozziAnalogRead(tempoPin);
  //volumeCont = 1;
  // read the knob
  int Pitch_value = mozziAnalogRead(Pitch_Pin); // value is 0-1023
   aSin.setFreq(Pitch_value); // set the frequency
  // map the knob to carrier frequency
  int carrier_freq = kMapCarrierFreq(Pitch_value);
  int mod_freq =0;

  //previous settings for mod
mod_freq = carrier_freq * mod_ratio;
 // }

  
  // set the FM oscillator frequencies
  //VOLUME CONTROL / DIGITAL INPUT X FREQ BY EITHER 1 OR 0 TO MUTE THE SOUND
    aCarrier.setFreq((carrier_freq)* volumeCont);
  //aCarrier.setFreq(carrier_freq); 
  aModulator.setFreq(mod_freq);
  
  // read the light dependent resistor on the width Analog input pin
  int LDR1_value= mozziAnalogRead(LDR1_PIN); // value is 0-1023
  

  int LDR1_calibrated = kMapIntensity(LDR1_value);
  
  
 // calculate the fm_intensity
  fm_intensity = ((long)LDR1_calibrated * (kIntensityMod.next()+128))>>8; // shift back to range after 8 bit multiply
 
  
  // read the light dependent resistor on the speed Analog input pin
  int LDR2_value= mozziAnalogRead(LDR2_PIN); // value is 0-1023
 
  
  // use a float here for low frequencies
float mod_speed = (float)kMapModSpeed(LDR2_value)/1000;
  //float mod_speed = 1000;
 
  kIntensityMod.setFreq(mod_speed);
  }


int updateAudio(){
long modulation = (aSmoothIntensity.next(fm_intensity) * aModulator.next()) * volumeCont;

//mode switch to select sound type played
 switch (ModeSelector1) {
      case 0:
       if(pulseOn == 1){
    return aCarrier.phMod(modulation);
       }
        break;
     case 1:
     //PLAY THE SINE WAVE IF THE PULSE IS ON
     if(pulseOn == 1){
     return aSin.next(); // return an int signal centred around 0
     }
     
        break;
      //default:
 }


}


void loop(){
  int pulseRatio = 30;
 
   audioHook();
 switch (ModeSelector1) {
      case 0:
    
        break;
     case 1:
        break;
      //default:
 }

  
  
 modeSwitch = digitalRead(modePin);
   unsigned long currentMillis = millis();
//interval = mozziAnalogRead(tempoPin);

if(modeSwitch == HIGH){
   if (currentMillis - previousMillis >= interval) {
    // save the last time you blinked the LED
    previousMillis = currentMillis;

    // if the LED is off turn it on and vice-versa:
    if (ledState == LOW) {
      ledState = HIGH;
      //volumeCont = 1;
      pulseOn = 1;
      digitalWrite(triggerPin, HIGH);
    } else {
      ledState = LOW;
      //volumeCont = 0;
      pulseOn = 0;
       digitalWrite(triggerPin, LOW);
    }

    // set the LED with the ledState of the variable:
    digitalWrite(ledPin, ledState);
  }
}}




